@@ -33,19 +33,20 @@ Mojo::Command::Generate::InitScript - Initscript generator command
 
 =head1 SYNOPSYS
 
+	$ ./mojo_app.pl generate help init_script
+	usage: ./mojo_app.pl generate init_script target_os [OPTIONS]
 
-  usage: ./script/my_app generate init_script target_os [OPTIONS]
+	These options are available:
+		--output <folder>   Set folder to output initscripts
+		--deploy            Deploy initscripts into OS
+							Either --deploy or --output=dist should be specified
 
-  These options are available:
-    --output <folder>   Set folder to output initscripts
-    --deploy            Deploy initscripts into OS
-                        Either --deploy or --output=dist should be specified
+		--name <name>       Ovewrite name which is used for initscript filename(s)
 
-    --name <name>       Ovewrite name which is used for initscript filename(s)
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 
